@@ -81,8 +81,13 @@ class TDeviceWin(TDeviceBase) :
             bflag = False
         return bflag
 
-    def SetTcLocalSave(this, boardID, bFlag) : 
-        return True #ted.SysSetTcLocalSave(boardID, bFlag)
+    def SysSetTcLocalSave(this, boardID, bFlag) : 
+        ret = this.__Api.TDeviceSysSetTcLocalSave(this.__DeviceHandle, boardID, bFlag)
+        if ret==1 :
+            bflag = True
+        else :
+            bflag = False
+        return bflag
         
     def Connect(this) :
         ret = this.__Api.TDeviceConnect(this.__DeviceHandle)
@@ -617,7 +622,7 @@ class TDeviceWin(TDeviceBase) :
 
 
     def ANA670X_SetFrameRate(this, dutIdx, fr) :
-        return this.__Api.TDeviceANA670X_SetFrameRate(this.__DeviceHandle, dutIdx)
+        return this.__Api.TDeviceANA670X_SetFrameRate(this.__DeviceHandle, dutIdx, fr)
 
     def ANA670X_GetFrameRate(this, dutIdx) : 
         return this.__Api.TDeviceANA670X_GetFrameRate(this.__DeviceHandle, dutIdx)
@@ -661,9 +666,10 @@ class TDeviceWin(TDeviceBase) :
         return bflag
 
 
-    #COMM_API Bool TedDD_DSIM_MipiWriteReg1Byte(int dutIdx, int addr, int byteOffset, unsigned char data);
+    #TDEVICE_API TED_BOOL TDeviceDD_DSIM_MipiWriteReg1Byte(void* hdl, int dutIdx, int addr, int byteOffset, unsigned char data);
     def DD_DSIM_MipiWriteReg1Byte(this, dutIdx, regAddr, byteOffset, regValue) : 
-        return this.__Api.TDeviceDD_DSIM_MipiReadReg1Byte(this.__DeviceHandle,  dutIdx, regAddr, byteOffset, regValue)
+        return this.__Api.TDeviceDD_DSIM_MipiWriteReg1Byte(this.__DeviceHandle,  dutIdx, regAddr, byteOffset, regValue)
+    
 
     #WREG0=0x39, [Addr], [regVal0], [regVal1].....
     def DD_DSIM_MipiWriteReg39(this, dutIdx, regAddr, regValueList) :
@@ -687,7 +693,7 @@ class TDeviceWin(TDeviceBase) :
 
     #WREG0=0x05, [Addr]
     def DD_DSIM_MipiWriteReg05(this, dutIdx, regAddr) :
-        ret = this.__Api.TDeviceDD_DSIM_MipiWriteReg05(this.__DeviceHandle, dutidx, regAddr)
+        ret = this.__Api.TDeviceDD_DSIM_MipiWriteReg05(this.__DeviceHandle, dutIdx, regAddr)
         if ret==1 :
             bflag = True
         else :
@@ -885,6 +891,9 @@ class TDeviceWin(TDeviceBase) :
     def AdcGetInvalidValue(this) : 
         return this.__Api.TDeviceAdcGetInvalidValue(this.__DeviceHandle)
 
+    def AdcGetInvalidFloat(this) : 
+        return this.__Api.TDeviceAdcGetInvalidFloat(this.__DeviceHandle)
+
     #COMM_API int TedAdcGetGroupCount(int dutIdx);
     def AdcGetGroupCount(this, dutIdx) : 
         return this.__Api.TDeviceAdcGetGroupCount(this.__DeviceHandle, dutIdx)
@@ -937,6 +946,9 @@ class TDeviceWin(TDeviceBase) :
     def AdcGetVoltage(this, dutIdx, grpIdx, chIdx) :
         return this.__Api.TDeviceAdcGetVoltage(this.__DeviceHandle, dutIdx, grpIdx, chIdx)
 
+    def AdcGetVoltFloat(this, dutIdx, grpIdx, chIdx) :
+        return this.__Api.TDeviceAdcGetVoltFloat(this.__DeviceHandle, dutIdx, grpIdx, chIdx)
+
     #COMM_API int TedAdcGetVoltageByPsID(int dutIdx, int psID);
     def AdcGetVoltageByPsID(this, dutIdx, psID) :
         return this.__Api.TDeviceAdcGetVoltageByPsID(this.__DeviceHandle, dutIdx, psID)
@@ -977,11 +989,33 @@ class TDeviceWin(TDeviceBase) :
 
         return adcList
 
+    #TDEVICE_API TED_BOOL TDeviceAdcGetAllVoltFloat(void* hdl, int dutIdx, int groupIdx, float* fvalueArray);
+    def AdcGetAllVoltFloat(this, dutIdx, grpIdx) : 
+
+        chCnt = this.AdcGetChannelCount(dutIdx, grpIdx)
+        adcList = [0.0 for _ in range(chCnt)]
+        
+        structFmt = "%df" % chCnt
+        #adcValueArrayBytes = struct.pack(structFmt, [0 for _ in range(chCnt)] )
+        #adcValueArrayBytes = struct.pack(structFmt, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0)
+
+        adcValueArrayBytes = bytes(chCnt*4)
+        this.__Api.TDeviceAdcGetAllVoltFloat(this.__DeviceHandle, dutIdx, grpIdx, adcValueArrayBytes)
+
+        result= struct.unpack(structFmt, adcValueArrayBytes)
+
+        for i in range(chCnt) :
+            adcList[i] = result[i]
+        
+        return adcList
 
     #COMM_API int TedAdcGetCurrent(int dutIdx, int groupIdx, int chIdx);
     def AdcGetCurrent(this, dutIdx, grpIdx, chIdx) :
         return this.__Api.TDeviceAdcGetCurrent(this.__DeviceHandle, dutIdx, grpIdx, chIdx)
 
+    def AdcGetCurrFloat(this, dutIdx, grpIdx, chIdx) :
+        return this.__Api.TDeviceAdcGetCurrFloat(this.__DeviceHandle, dutIdx, grpIdx, chIdx)
+
     #COMM_API int TedAdcGetCurrentByPsID(int dutIdx, int psID);
     def AdcGetCurrentByPsID(this, dutIdx, psID) :
         return this.__Api.TDeviceAdcGetCurrentByPsID(this.__DeviceHandle, dutIdx, psID)
@@ -1004,6 +1038,22 @@ class TDeviceWin(TDeviceBase) :
 
         return adcList
 
+    #TDEVICE_API TED_BOOL TDeviceAdcGetAllCurrFloat(void* hdl, int dutIdx, int groupIdx, float* fvalueArray);
+    def AdcGetAllCurrFloat(this, dutIdx, grpIdx) : 
+
+        chCnt = this.AdcGetChannelCount(dutIdx, grpIdx)
+        adcList = [0.0 for _ in range(chCnt)]
+        structFmt = "%df" % chCnt
+        adcValueArrayBytes = bytes(chCnt*4)
+        this.__Api.TDeviceAdcGetAllCurrFloat(this.__DeviceHandle, dutIdx, grpIdx, adcValueArrayBytes)
+
+        result= struct.unpack(structFmt, adcValueArrayBytes)
+
+        for i in range(chCnt) :
+            adcList[i] = result[i]
+        
+        return adcList
+
     #COMM_API Bool TedAdcSoutSetRBSel(int dutIdx, int value);
     def AdcSoutSetRBSel(this, dutIdx, value) :
         return this.__Api.TDeviceAdcSoutSetRBSel(this.__DeviceHandle, dutIdx, value)
@@ -1012,98 +1062,64 @@ class TDeviceWin(TDeviceBase) :
     def AdcSoutGetRBSel(this, dutIdx) :
         return this.__Api.TDeviceAdcSoutGetRBSel(this.__DeviceHandle, dutIdx)
 
+    #TDEVICE_API TED_BOOL TDeviceAdcGetAllFloat(void* hdl, int dutIdx, int groupIdx, float* fVoltArray, float* fCurrArray)
+    def AdcGetAllFloat(this, dutIdx, grpIdx) : 
 
-#
-# class TFileTransfer
-#
-class TFileTransfer :
+        chCnt = this.AdcGetChannelCount(dutIdx, grpIdx)
+        adcList = [0.0 for _ in range(chCnt*2)]
 
-    class Type(enum.IntEnum) : 
-        T5 = 0
+        structFmt = "%df" % chCnt
+        adcVoltArrayBytes = bytes(chCnt*4)
+        adcCurrArrayBytes = bytes(chCnt*4)
+        this.__Api.TDeviceAdcGetAllFloat(this.__DeviceHandle, dutIdx, grpIdx, adcVoltArrayBytes, adcCurrArrayBytes)
+
+        result= struct.unpack(structFmt, adcVoltArrayBytes)
+        for i in range(chCnt) :
+            adcList[i] = result[i]
         
-    class ErrorType(enum.IntEnum) : 
-        Success = 0,
-        SendPacket=1,
-        NoResp=2,
-        FileOpen=3,
-        StorageSize=4,
-        CRC=5
-    
+        result= struct.unpack(structFmt, adcCurrArrayBytes)
+        for i in range(chCnt) :
+            adcList[i + chCnt] = result[i]
+
+        return adcList
+
     #TDEVICE_API TFILETRANSFER_HDL TFileTransferCreate(enum TFileTransferType type, TDEVICE_HDL deviceHandle);
-    def __init__(this, type, device) :
-        this.__TFileTransferHandle = TFileTransferCreate(type, device.Handle)
-        this.__FileName = ""
-
-    def __getattr__(this, attrName) :
-        if attrName == 'LastErrorString' : 
-            return this.GetLastErrorString()
-        if attrName == 'FileName' : 
-            return this.__FileName
-        else :
-            raise AttributeError(attrName)
-
+    def TFileTransferCreate(this, type) : 
+        return this.__Api.TFileTransferCreate(type, this.__DeviceHandle)
 
     #TDEVICE_API TED_BOOL TFileTransferDestroy(TFILETRANSFER_HDL fileTransferHandle);
-
+    def TFileTransferDestroy(this, fileTransferHandle) : 
+        return this.__Api.TFileTransferDestroy(fileTransferHandle)
+    
     #TDEVICE_API TED_BOOL TFileTransferStart(TFILETRANSFER_HDL fileTransferHandle, const char* fileName);
-    def Start(this, fileName) : 
-        this.__FileName = fileName
-        bytesString = fileName.encode('euc-kr')
-        #bytesString = fileName.encode('ascii')
-        #bytesString = fileName.encode('utf-8')
-        ret = TFileTransferStart(this.__TFileTransferHandle, bytesString)
-        return ret
+    def TFileTransferStart(this, fileTransferHandle, fileName) : 
+        return this.__Api.TFileTransferStart(fileTransferHandle, fileName)
 
     #TDEVICE_API TED_BOOL TFileTransferStop(TFILETRANSFER_HDL fileTransferHandle);
-    def Stop(this) : 
-        ret = TFileTransferStop(this.__TFileTransferHandle)
-        return ret
-
+    def TFileTransferStop(this, fileTransferHandle) : 
+        return this.__Api.TFileTransferStop(fileTransferHandle)
+    
     #TDEVICE_API int TFileTransferGetFileByteSize(TFILETRANSFER_HDL fileTransferHandle);
-    def GetFileByteSize(this) : 
-        ret = TFileTransferGetFileByteSize(this.__TFileTransferHandle)
-        return ret
-
+    def TFileTransferGetFileByteSize(this, fileTransferHandle) : 
+        return this.__Api.TFileTransferGetFileByteSize(fileTransferHandle)
+        
     #TDEVICE_API int TFileTransferGetTransferByteSize(TFILETRANSFER_HDL fileTransferHandle);
-    def GetTransferByteSize(this) : 
-        ret = TFileTransferGetTransferByteSize(this.__TFileTransferHandle)
-        return ret
+    def TFileTransferGetTransferByteSize(this, fileTransferHandle) : 
+        return this.__Api.TFileTransferGetTransferByteSize(fileTransferHandle)
 
     #TDEVICE_API TED_BOOL TFileTransferIsStart(TFILETRANSFER_HDL fileTransferHandle);
-    def IsStart(this) : 
-        ret = TFileTransferIsStart(this.__TFileTransferHandle)
-        return ret
-
+    def TFileTransferIsStart(this, fileTransferHandle) : 
+        return this.__Api.TFileTransferIsStart(fileTransferHandle)
+    
     #TDEVICE_API TED_BOOL TFileTransferIsDone(TFILETRANSFER_HDL fileTransferHandle);
-    def IsDone(this) : 
-        ret = TFileTransferIsDone(this.__TFileTransferHandle)
-        return ret
+    def TFileTransferIsDone(this, fileTransferHandle) : 
+        return this.__Api.TFileTransferIsDone(fileTransferHandle)
 
     #TDEVICE_API TED_BOOL TFileTransferIsError(TFILETRANSFER_HDL fileTransferHandle);
-    def IsError(this) : 
-        ret = TFileTransferIsError(this.__TFileTransferHandle)
-        return ret
-
+    def TFileTransferIsError(this, fileTransferHandle) : 
+        return this.__Api.TFileTransferIsError(fileTransferHandle)
+        
     #TDEVICE_API enum TFileTransferError TFileTransferGetLastError(TFILETRANSFER_HDL fileTransferHandle);
-    def GetLastError(this) : 
-        ret = TFileTransferGetLastError(this.__TFileTransferHandle)
-        return ret
+    def TFileTransferGetLastError(this, fileTransferHandle) : 
+        return this.__Api.TFileTransferGetLastError(fileTransferHandle)
 
-    def GetLastErrorString(this) :
-        err = this.GetLastError()
-        if err == TFileTransfer.ErrorType.Success :
-            return "Success"
-        elif err == TFileTransfer.ErrorType.SendPacket :
-            return "SendPacket Error"
-        elif err == TFileTransfer.ErrorType.NoResp :
-            return "NoResp Error"
-        elif err == TFileTransfer.ErrorType.FileOpen :
-            return "FileOpen Error"
-        elif err == TFileTransfer.ErrorType.StorageSize :
-            return "StorageSize Error"
-        elif err == TFileTransfer.ErrorType.CRC :
-            return "CRC Error"
-        else :
-            return "Unknown Error"
-    
-    
\ No newline at end of file
