@@ -90,8 +90,8 @@ class TDevice :
     def SysSetBoardID(this, boardID) : 
         return this.__TDevice.SysSetBoardID(boardID)
     
-    def SetTcLocalSave(this, boardID, bFlag) : 
-        return this.__TDevice.SetTcLocalSave(boardID, bFlag)
+    def SysSetTcLocalSave(this, boardID, bFlag) : 
+        return this.__TDevice.SysSetTcLocalSave(boardID, bFlag)
     
     def SysGetDefaultDutIndex(this) : 
         return 0
@@ -443,6 +443,9 @@ class TDevice :
     def AdcGetInvalidValue(this) : 
         return this.__TDevice.AdcGetInvalidValue()
 
+    def AdcGetInvalidFloat(this) : 
+        return this.__TDevice.AdcGetInvalidFloat()
+
     #COMM_API int TedAdcGetGroupCount(int dutIdx);
     def AdcGetGroupCount(this, dutIdx) : 
         return this.__TDevice.AdcGetGroupCount(dutIdx)
@@ -491,6 +494,9 @@ class TDevice :
     def AdcGetVoltage(this, dutIdx, grpIdx, chIdx) :
         return this.__TDevice.AdcGetVoltage(dutIdx, grpIdx, chIdx)
 
+    def AdcGetVoltFloat(this, dutIdx, grpIdx, chIdx) :
+        return this.__TDevice.AdcGetVoltFloat(dutIdx, grpIdx, chIdx)
+
     #COMM_API int TedAdcGetVoltageByPsID(int dutIdx, int psID);
     def AdcGetVoltageByPsID(this, dutIdx, psID) :
         return this.__TDevice.AdcGetVoltageByPsID(dutIdx, psID)
@@ -503,10 +509,16 @@ class TDevice :
     def AdcGetAllVoltage(this, dutIdx, grpIdx) :
         return this.__TDevice.AdcGetAllVoltage(dutIdx, grpIdx)
 
+    def AdcGetAllVoltFloat(this, dutIdx, grpIdx) :
+        return this.__TDevice.AdcGetAllVoltFloat(dutIdx, grpIdx)
+
     #COMM_API int TedAdcGetCurrent(int dutIdx, int groupIdx, int chIdx);
     def AdcGetCurrent(this, dutIdx, grpIdx, chIdx) :
         return this.__TDevice.AdcGetCurrent(dutIdx, grpIdx, chIdx)
 
+    def AdcGetCurrFloat(this, dutIdx, grpIdx, chIdx) :
+        return this.__TDevice.AdcGetCurrFloat(dutIdx, grpIdx, chIdx)
+
     #COMM_API int TedAdcGetCurrentByPsID(int dutIdx, int psID);
     def AdcGetCurrentByPsID(this, dutIdx, psID) :
         return this.__TDevice.AdcGetCurrentByPsID(dutIdx, psID)
@@ -519,6 +531,12 @@ class TDevice :
     def AdcGetAllCurrent(this, dutIdx, grpIdx) :
         return this.__TDevice.AdcGetAllCurrent(dutIdx, grpIdx)
 
+    def AdcGetAllCurrFloat(this, dutIdx, grpIdx) :
+        return this.__TDevice.AdcGetAllCurrFloat(dutIdx, grpIdx)
+
+    def AdcGetAllFloat(this, dutIdx, grpIdx) :
+        return this.__TDevice.AdcGetAllFloat(dutIdx, grpIdx)
+
     #COMM_API Bool TedAdcSoutSetRBSel(int dutIdx, int value);
     def AdcSoutSetRBSel(this, dutIdx, value) :
         return this.__TDevice.AdcSoutSetRBSel(dutIdx, value)
@@ -527,7 +545,144 @@ class TDevice :
     def AdcSoutGetRBSel(this, dutIdx) :
         return this.__TDevice.AdcSoutGetRBSel(dutIdx)
 
+    #TDEVICE_API TFILETRANSFER_HDL TFileTransferCreate(enum TFileTransferType type, TDEVICE_HDL deviceHandle);
+    def TFileTransferCreate(this, type) : 
+        return this.__TDevice.TFileTransferCreate(type)
 
+    #TDEVICE_API TED_BOOL TFileTransferDestroy(TFILETRANSFER_HDL fileTransferHandle);
+    def TFileTransferDestroy(this, fileTransferHandle) : 
+        return this.__TDevice.TFileTransferDestroy(fileTransferHandle)
+    
+    #TDEVICE_API TED_BOOL TFileTransferStart(TFILETRANSFER_HDL fileTransferHandle, const char* fileName);
+    def TFileTransferStart(this, fileTransferHandle, fileName) : 
+        return this.__TDevice.TFileTransferStart(fileTransferHandle, fileName)
+
+    #TDEVICE_API TED_BOOL TFileTransferStop(TFILETRANSFER_HDL fileTransferHandle);
+    def TFileTransferStop(this, fileTransferHandle) : 
+        return this.__TDevice.TFileTransferStop(fileTransferHandle)
+    
+    #TDEVICE_API int TFileTransferGetFileByteSize(TFILETRANSFER_HDL fileTransferHandle);
+    def TFileTransferGetFileByteSize(this, fileTransferHandle) : 
+        return this.__TDevice.TFileTransferGetFileByteSize(fileTransferHandle)
+        
+    #TDEVICE_API int TFileTransferGetTransferByteSize(TFILETRANSFER_HDL fileTransferHandle);
+    def TFileTransferGetTransferByteSize(this, fileTransferHandle) : 
+        return this.__TDevice.TFileTransferGetTransferByteSize(fileTransferHandle)
+
+    #TDEVICE_API TED_BOOL TFileTransferIsStart(TFILETRANSFER_HDL fileTransferHandle);
+    def TFileTransferIsStart(this, fileTransferHandle) : 
+        return this.__TDevice.TFileTransferIsStart(fileTransferHandle)
+    
+    #TDEVICE_API TED_BOOL TFileTransferIsDone(TFILETRANSFER_HDL fileTransferHandle);
+    def TFileTransferIsDone(this, fileTransferHandle) : 
+        return this.__TDevice.TFileTransferIsDone(fileTransferHandle)
+
+    #TDEVICE_API TED_BOOL TFileTransferIsError(TFILETRANSFER_HDL fileTransferHandle);
+    def TFileTransferIsError(this, fileTransferHandle) : 
+        return this.__TDevice.TFileTransferIsError(fileTransferHandle)
+        
+    #TDEVICE_API enum TFileTransferError TFileTransferGetLastError(TFILETRANSFER_HDL fileTransferHandle);
+    def TFileTransferGetLastError(this, fileTransferHandle) : 
+        return this.__TDevice.TFileTransferGetLastError(fileTransferHandle)
+
+
+##############################################################################################################################
+#
+# class TFileTransfer
+#
+##############################################################################################################################
+
+class TFileTransfer :
+
+    class Type(enum.IntEnum) : 
+        T5 = 0
+        
+    class ErrorType(enum.IntEnum) : 
+        Success = 0,
+        SendPacket=1,
+        NoResp=2,
+        FileOpen=3,
+        StorageSize=4,
+        CRC=5
+    
+    #TDEVICE_API TFILETRANSFER_HDL TFileTransferCreate(enum TFileTransferType type, TDEVICE_HDL deviceHandle);
+    def __init__(this, type, device) :
+        this.__TFileTransferHandle = device.TFileTransferCreate(type)
+        this.__FileName = ""
+        this.__Device = device;
+
+    def __getattr__(this, attrName) :
+        if attrName == 'LastErrorString' : 
+            return this.GetLastErrorString()
+        if attrName == 'FileName' : 
+            return this.__FileName
+        else :
+            raise AttributeError(attrName)
+
+
+    #TDEVICE_API TED_BOOL TFileTransferDestroy(TFILETRANSFER_HDL fileTransferHandle);
+
+    #TDEVICE_API TED_BOOL TFileTransferStart(TFILETRANSFER_HDL fileTransferHandle, const char* fileName);
+    def Start(this, fileName) : 
+        this.__FileName = fileName
+        bytesString = fileName.encode('euc-kr')
+        #bytesString = fileName.encode('ascii')
+        #bytesString = fileName.encode('utf-8')
+        ret = this.__Device.TFileTransferStart(this.__TFileTransferHandle, bytesString)
+        return ret
+
+    #TDEVICE_API TED_BOOL TFileTransferStop(TFILETRANSFER_HDL fileTransferHandle);
+    def Stop(this) : 
+        ret = this.__Device.TFileTransferStop(this.__TFileTransferHandle)
+        return ret
+
+    #TDEVICE_API int TFileTransferGetFileByteSize(TFILETRANSFER_HDL fileTransferHandle);
+    def GetFileByteSize(this) : 
+        ret = this.__Device.TFileTransferGetFileByteSize(this.__TFileTransferHandle)
+        return ret
+
+    #TDEVICE_API int TFileTransferGetTransferByteSize(TFILETRANSFER_HDL fileTransferHandle);
+    def GetTransferByteSize(this) : 
+        ret = this.__Device.TFileTransferGetTransferByteSize(this.__TFileTransferHandle)
+        return ret
+
+    #TDEVICE_API TED_BOOL TFileTransferIsStart(TFILETRANSFER_HDL fileTransferHandle);
+    def IsStart(this) : 
+        ret = this.__Device.TFileTransferIsStart(this.__TFileTransferHandle)
+        return ret
+
+    #TDEVICE_API TED_BOOL TFileTransferIsDone(TFILETRANSFER_HDL fileTransferHandle);
+    def IsDone(this) : 
+        ret = this.__Device.TFileTransferIsDone(this.__TFileTransferHandle)
+        return ret
+
+    #TDEVICE_API TED_BOOL TFileTransferIsError(TFILETRANSFER_HDL fileTransferHandle);
+    def IsError(this) : 
+        ret = this.__Device.TFileTransferIsError(this.__TFileTransferHandle)
+        return ret
+
+    #TDEVICE_API enum TFileTransferError TFileTransferGetLastError(TFILETRANSFER_HDL fileTransferHandle);
+    def GetLastError(this) : 
+        ret = this.__Device.TFileTransferGetLastError(this.__TFileTransferHandle)
+        return ret
+
+    def GetLastErrorString(this) :
+        err = this.GetLastError()
+        if err == TFileTransfer.ErrorType.Success :
+            return "Success"
+        elif err == TFileTransfer.ErrorType.SendPacket :
+            return "SendPacket Error"
+        elif err == TFileTransfer.ErrorType.NoResp :
+            return "NoResp Error"
+        elif err == TFileTransfer.ErrorType.FileOpen :
+            return "FileOpen Error"
+        elif err == TFileTransfer.ErrorType.StorageSize :
+            return "StorageSize Error"
+        elif err == TFileTransfer.ErrorType.CRC :
+            return "CRC Error"
+        else :
+            return "Unknown Error"
+    
 
 
 ##############################################################################################################################
